# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ...._models import BaseModel

__all__ = ["ActionScreenshotResponse"]


class ActionScreenshotResponse(BaseModel):
    uri: str
    """URL of the screenshot"""
